==> 1.3-2.tar.gz: ldapsaisie/public_html/includes/class/class.LSformRule_alphanumeric.php <==
<?php
/*******************************************************************************
 * Copyright (C) 2007 Easter-eggs
 * http://ldapsaisie.labs.libre-entreprise.org
 *
 * Author: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

/**
 * Règle de validation d'une valeur alpha-numérique.
 *
 * @author Benjamin Renard <brenard@easter-eggs.com>
 */
class LSformRule_alphanumeric extends LSformRule {
  
  /**
   * Vérification de la valeur.
   *
   * @param string $value  Value à vérifier
   * @param array $options Options de validation (inutile ici)
   * @param object $formElement L'objet formElement attaché
   *
   * @return boolean true si la valeur est valide, false sinon
   */
  function validate ($value,$options=array(),$formElement) {


     if (isset($options['params']['withAccents']) && $options['params']['withAccents'] == true){
         $regex = '/(*UTF8)^[0-9\p{L}]+$/';
     }
     else {
         $regex = '/^[a-zA-Z0-9]+$/';
     }
     LSsession :: loadLSclass('LSformRule_regex');
     return LSformRule_regex :: validate($value,$regex,$formElement);

  }
  
}

?>

==> 1.7-1.tar.gz: ldapsaisie/public_html/includes/class/class.LSformRule_alphanumeric.php <==
<?php
/*******************************************************************************
 * Copyright (C) 2007 Easter-eggs
 * http://ldapsaisie.labs.libre-entreprise.org
 *
 * Author: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

/**
 * Règle de validation d'une valeur alpha-numérique.
 *
 * @author Benjamin Renard <brenard@easter-eggs.com>
 */
class LSformRule_alphanumeric extends LSformRule {
  
  /**
   * Vérification de la valeur.
   *
   * @param string $value  Value à vérifier
   * @param array $options Options de validation :
   *                          - $options['params']['withAccents'] : set if accents is allowed
   * @param object $formElement L'objet formElement attaché
   *
   * @return boolean true si la valeur est valide, false sinon
   */
  function validate ($value,$options=array(),$formElement) {


     if (isset($options['params']['withAccents']) && $options['params']['withAccents'] == true){
         $regex = '/(*UTF8)^[0-9\p{L}]+$/';
     }
     else {
         $regex = '/^[a-zA-Z0-9]+$/';
     }
     LSsession :: loadLSclass('LSformRule_regex');
     return LSformRule_regex :: validate($value,$regex,$formElement);

  }
  
}
